![](resources/skooting_in_progress_v2.png)

# SKOOTS

<img src="resources/overview.png" align="center" width="150px"/> 
SKeletOn ObjecT Segmentation - 2D/3D instance segmentation of arbitrary biomedical images.

Currently, in development! Things may change!

Makes use of BISM (Biomedical Image Segmentation Models) and a lot of pyTorch

## <img src="resources/installation.png" align="center" width="150px"/>

<!-- start installation -->
To install, make sure pyTorch is installed with CUDA support.

```bash
pip install skoots
```

<!-- end installation -->

## Usage

<img src="resources/usage.png" align="center" width="150px"/> 
test

## Considerations

<img src="resources/considerations.png" align="center" width="150px"/> 
test

## Warnings

<img src="resources/warning.png" align="center"/> 
test


